.. Static Media Manager documentation master file, created by
   sphinx-quickstart on Mon Oct 19 09:12:09 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Static Media Manager's documentation!
================================================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   getting_started
   settings
   css_compression
   js_compression
   management_commands
   app_media
   reference/*

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

